task spladder_EC {
    String sample_id
    File bam
    File pickle
    File merge_graphs
    File count_hdf5
    File reference_gtf_file
    File samples
    File merge_count_hdf5
    
    String event_types
    String spladder_docker
    String spladder_cluster
    String disk_size

    
    command <<<
        set -o pipefail
        set -e

        mkdir -p ${sample_id}/spladder_out/spladder
        
        ln -s ${bam}/*.bam ./
        cat ${samples} | while read a; do ls ./ | grep bam$ | grep $a; done > alignment.txt
       
        ln -s ${bam}/*.bai ./
        cat ${samples} | while read a; do ls ./ | grep bai$ | grep $a; done > alignment_bai.txt

        ln -s ${pickle}/*.pickle ${sample_id}/spladder_out/spladder/
        cat ${samples} | while read a; do ls ${sample_id}/spladder_out/spladder/| grep pickle$| grep $a; done >> pickle.txt
		
        cp -r ${merge_graphs} ${sample_id}/spladder_out/spladder/
        cp -r ${merge_count_hdf5} ${sample_id}/spladder_out/spladder/ 

        cp -r ${count_hdf5}/* ${sample_id}/spladder_out/spladder/
        cat ${samples} | while read a; do ls ${sample_id}/spladder_out/spladder/| grep count| grep $a; done >> count.txt


        nt=$(nproc)
		
        spladder build -o ${sample_id}/spladder_out \
          --annotation ${reference_gtf_file} \
          --bams alignment.txt \
          --confidence 2 \
          --merge-strat merge_graphs \
          --readlen 150 \
          --parallel $nt \
          --event-types ${event_types}
          
          
        find . -depth > fileList.txt
    >>>

    runtime {
        docker: spladder_docker
        cluster: spladder_cluster
        systemDisk: "cloud_ssd 50"
        dataDisk: "cloud_ssd " + disk_size + " /cromwell_root/"
        timeout: 129600
    }

    output {
        File fileList = "fileList.txt"
        File alignment = "alignment.txt"
        File alignment_bai = "alignment_bai.txt"
        File pickle_txt = "pickle.txt"
        File count_hdf5_txt = "count.txt"
        Array[File] AS_gff = glob("${sample_id}/spladder_out/*.gff3")
        Array[File] AS_gz = glob("${sample_id}/spladder_out/*.gz")
        Array[File] spladder_out = glob("${sample_id}/spladder_out/*")
        Array[File] spladder = glob("${sample_id}/spladder_out/spladder/*")
    }
}